import unittest
import numpy as np
import sys
import os
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../src/pynirs")

FILE_0 = os.path.join(os.path.dirname(__file__), 'test_set0.csv')

from nirs_set import NIRS_Set as NSet

class TestLoadMethods(unittest.TestCase):
    
    def test_singleFile(self):
        n = NSet("test")
        n.load(FILE_0, y_cols = 0)
        self.assertEqual(n.get_raw_x().shape, (3,62))
        self.assertEqual(n.get_raw_y().shape, (3,1))
        
        n.load(FILE_0, y_cols = [0,1])
        self.assertEqual(n.get_raw_x().shape, (3,61))
        self.assertEqual(n.get_raw_y().shape, (3,2))
        



if __name__ == '__main__':
    runittest.main()


mYotxGkCHWofaBdVdTobtMhHbZoWuWDFHwQohZolJyfYJqVPBElYHZBxqBShSvQyVJfOVLfnXUmvNgl100 = "dDOvNWchOgbvbQDvUDSlbeAroyvEOfHeyDLjDxLyrdooAHiDlrgBHJQlqCMdTYJhpNMWNzWRMBPjpVU"
wkaRNJnfbwEKRiksXXBoMMzNLsNcPzRNIToxRIbJxByaWgERccDCqUFMsXEXKhNCjiukKnGJlfoywre98 = 806
AAAAaaAaAAAaaAAaaAaAaaaAAaAaAAaaaaaaaAaAAAaaaAaAAaAAaaaAaaaAAAAaaaaAaAaaaaaaaaaAaAaaaaAaaaaAAAaA = "JgxuJpFRhYDnRUCivVBxwJjUbCHzcloNhokEqzvRPHFEAIXgPEoXZYkajzxsPzNVfNmtvNilRVSqaMQ"
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC = 167
YFLEdxZKQpKIzKTzVtJwFUrAbbgVttCQUiDNzWegwdqOZVngIcPROZbxHkbGEZDwWWVbueuLfrusemh92 = "SlWjWEkSaUQoBcBcBKsQSnpRRjFnrqVdzUkrlKIUiPNgNVRfcaHAZCxUadUnugtrBMDUkOdgBRrVKMy"
lllIllIIllIIllIIIIlIIIIIIlllIlIllIllllllllIlIlllIlIlllIllIllIlIIlIllIIIIIIlIllllllIIllllll = 114
lllllIlllIlIllIIIIlIlllIIlllIIIIIlIIllIIlIlIIIIIllIIIIIIllIIlllIlIIIIIIllIllIIlIIIIllIII = 451
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc = "JmeieSBAZWXTEuAJmGTAroEmxNOQmzZgUedJqAoYMndYwNEXMVZMiaqujfUfbqlWJkVodAXkuXcYEWG"
BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB = 365
GGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGG = "GMjwoPgaRIUSVmpakZUuBZDbRvtFAfgIfRXuItMZSjMTmSvpBdoCiLLlaxjNlLTJuinCKAXnspVascy"
H1655195582878416380 = "pxAqBmhkEbxgabvnheEeilAUXLZPlcOxohmeqxAIKLerxOAjhluBubjbDpXfcjXrgSUEVhbfagbTSxU"
AAAAAaaaAaaAAaAaAaaaAaAAAaAaAaAAAaaAaaAAaAAaaAaAAAAaAaaAAAAaAaaaAaaAAAaAaAaAAa = "usHchqaGuxzLGqfuKqziIBFXAoCBXPyBtWFsQtAjmbExzWhgXZThBIeSpiyyKYgufaFvcqJeHpHQTsf"
M1655195582878416376 = 316
Q1655195582878416374 = 243
G1655195582878416372 = 391
PyPRDTzJRqzGmTzpQqWVhhTkWJpvbdtxNKEkqgpvTSRJNKiVeYaRmgzunpSOQdYzllVidOCRiVnjeFH70 = 569
y1655195582878416368 = 619
lllIlIIlIIlIlIIlIlIlIIllIlIlIlIllllllIIIllllIIIlIllIIllIIIIlIIlIII = "YdZrCCJOPtswSPsaTtctrcxqHWbdWBKAQecgStizZwAOdZZhIXwQYPzRLlgIEgNIVWmtKTaGbJaxPND"
v64 = 380
J62 = "UtHbVVLtPyCPJOuyozJKgtQreiddYYWIefUkPyjbmhXOMzUxCIojlbcOARdiHOPPqPDhuPdmtERVJAV"
aAAaAAAaAAaaaaaaAaaaaaaAAaAaaAaAaaaaaAAAaAaaaAAaaAaAaAAAaAAA = 274
aaaAAAaAaAAAaAAaaaAaaaAAAaAaaAAaaAAAAAaAAaaaaaaAaAaaaAAaAa = 286
PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP = "thCojphegurUzsQLApUOKpFaORGpfpXynJdaOjQRHDfIPyEjdkazeDOKtAyPvYIWbLteJtbUIoQTYfU"
aAaAaaaAaAAaAaaaaaAAaaaaAAaAAaAAaaaaaAaAaAAaaaaAaaAaaa = "JHjVgYSMQWHvPTIMKWGYdZAPzZjBqGcCMGaPjtBJuWaePjuBODgGuNmibtQwABZdPqQEqItfYmTaOri"
LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL = "xLGSQrInQZhACPfgySUXssRLmsONhkzYiNjxJZKVOwRwyPDGoRwXhGFIxzZiaKgAfsZSSefPCDMzSKR"
FlHMoArPIeVsXNcbPFBsWOWVIChLSRgSuAsQRLIwEcornboqPZwmztheiRluUatGYuuCVlQOZwSzBSU50 = "gpqLgjkXoAcyfojTjZnsSJcvhKcfjqIhdqEeHgLXkVMgahgVhPOwIzNNVvydgTpgdWkWSAQYtnKvjYm"
jnbnurwsXlwhhoivCYFXZAXtKYfKKSOQeSHBzTkLFQtIQzgnyZZvgxowUHCZLKUXHOiGlfEJcilTHKb48 = "sWkdVoHwVpMqGsyMtbTwBjOViCiWhFNOzNUTCicWtXIhhOZbVQigsBTXkvrcCTsuPlMyRkDctJLvUSK"
f46 = 333
aaaAAaAAAAaAAaaAaAAaAAaAAAAaAAaaaAAAAaaaaaaa = "lLiVuEhxtHaOvCRvuaVrFisMcSSSdVAeEWWJBipFKvqMBaEkWTZgkaFQFnsGtqWKoJkHgSLjiQIsoFF"
Z165519558287539542 = 400
aAAAaAaAaAAaAAAaaAaAAaaAaAaAAAAaaAaaAAAA = "WELIerRLsGGjVNtZeofjCyUuGsKfjLREniJoluimxENHwPWVfVtbSjPyGaYBukdobEFTRzFzgArkFqu"
AAaAaAAaaaAAAaaaaAaAaAAaAAaAAaaaAAaaAA = 453
M165519558287539536 = 382
O165519558287539534 = "YZvwoFutcdkOnCXzjZnVMJFxtFPhcGOnhgMFkxXefaXrxAAYaoRVPqbcYouBQrfzcrVHDKoDVSrurHp"
WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW = 132
aAaAaaaAaaAAAaaaAAAAaaAaaaAAaA = 246
W165519558287539528 = "eDEdfTVdWSRNdlfdxgggqQXywjOzZLqprCzFANJfQopQvOwKnqlmrgwmYCZXrYzCPmmREhAffwhFwMy"
lIIIlIIllllIIIlllIIIlIllIl = 317
jjjjjjjjjjjjjjjjjjjjjjjj = "WPdiWXRLVzYJVHDuZOUoNsZIJJpHwTcrtDNThzschbNodiUSxsOIjSXMAdYuWtsKhPXZlIkLHHZpybw"
KaqwoUaYQcfXFDArwroTnosSXGAvMffadzyPdBUJznWjeyisSVgrmcCrkzrjAAbgoTMkENTgkozKOuv22 = 262
SGoukqsboJRnVjwMgGpPMicwHvPeroTxwAjuZYvSpuQVfZbvixzmGQUxTSauQrlZzxZvcXjIhxJpmna20 = "LDvGFmSCHYYKcHVMmFqGgoMOfXrgHuPSvMubbmDHSRjOrjYTwIeYfqkKzkBCGhfCYytjBpJKSyCDOBm"
b18 = 404
YYYYYYYYYYYYYYYY = 338
q1655195582874394714 = "RQgVZoEcBLcHISmKJUzOpFOlmnlSvhFLNIbzlzLiqOxAbYvxXBoOPcvqJaqcvoyMIAzzJnSBNEkbqno"
IlllllIlllll = "VdDAwiBtdJszygqWMhTUsiFTogoPfhZKfAFzoWKNYpRHDQKhCQnhHnwAteqirAZSsjWgJNEGPBTZmdJ"
skNChOlgHGQTFNQjSYJHrAttBQFJoReEaexYTzgxBuqQDPdySpOcYigsCdVQrmRJGqoFeWihjvcEqSh10 = "VqBMnKcfKZxeFhoYNlXwzZblCMolauIIOiveBxPQxuZnjysLGpawMdJZcznjvNoGpHutknJBsijxEKJ"
C8 = "wDZLOJJAhbVJemttknrPtmiWrjkrwFeqYyIxSQpXhrLTalDWoMVGmkbxGKtdmviyBOSYJqMbhpkJHBs"
JdxYCjmxqDgMJKUpakdpoaVKudaVpvIzVRwOWXyZFOrKsOPSiboznSDHBkdSiZwIXTSKksCmLuvyZFv6 = "GTIhTpfSziXBnWzGWKUwKWmffXFzKvtbqENcuNIJLpBPMgmAFuEPTgbxDcBdxBzqXwRTdSEnMGVjbDr"
A165519558287339454 = "ccVALImaaozXfrHGxKlCFCiIhBZduoWGXjpOgooXYiWwpkLbzbHfdpASumLSxoyyBDxCoAwhZTLViHr"
P165519558287339452 = 435

import warnings
import numpy as np
from sklearn.base import TransformerMixin, BaseEstimator
import random ## TODO replace by np.random
import scipy.interpolate as interpolate

############################
##    HELPERS FUNCTIONS   ##
############################

def anglePointFixe(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44,HhnIuwlQbRKXnURZHbsqPNtBVhYUAkJPaJxxbGjkaBynfyBmCUGALidROFGxxTjMgOcVIPkTTRJFvbQ35,h165519558278939636,A34,AAAaaaaaaaaAAaAaAAAaAaAAaAAAaaAAa):   
    if eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 <= HhnIuwlQbRKXnURZHbsqPNtBVhYUAkJPaJxxbGjkaBynfyBmCUGALidROFGxxTjMgOcVIPkTTRJFvbQ35:
        return(A34*(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44-HhnIuwlQbRKXnURZHbsqPNtBVhYUAkJPaJxxbGjkaBynfyBmCUGALidROFGxxTjMgOcVIPkTTRJFvbQ35)+h165519558278939636)
    else:
        return(AAAaaaaaaaaAAaAaAAAaAaAAaAAAaaAAa*(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44-HhnIuwlQbRKXnURZHbsqPNtBVhYUAkJPaJxxbGjkaBynfyBmCUGALidROFGxxTjMgOcVIPkTTRJFvbQ35)+h165519558278939636)

AAAaaAaaAaAAaAaaaaaAAaAAAaAaaAaAaaAAAAaaAAAAaAAAaaAaaaaAa = np.vectorize(anglePointFixe)


def segment_length(Y165519558276941563,zMpyPJjnNWFhRfpwARoniwwJKELFTTayXPksjNlAhxpZFLsHLBValVWzulltRcLEFxMJbFmlZHCwdFq4,nqjDPlPKImakuPauEKMZBNJYmGPuRpYykevtNFymLGfjidskqvzNPufDnCpPKrWRsbOlugbxYSHOFNj5,htRAsoxSTCFxiufxXZEzOphdxQujuWTZHTTelDdGSKqLrAAzNMHRemUjlYLnsvobgZTvYgNkHDrjRYM6):
    return(np.sqrt((nqjDPlPKImakuPauEKMZBNJYmGPuRpYykevtNFymLGfjidskqvzNPufDnCpPKrWRsbOlugbxYSHOFNj5-Y165519558276941563)**2+(htRAsoxSTCFxiufxXZEzOphdxQujuWTZHTTelDdGSKqLrAAzNMHRemUjlYLnsvobgZTvYgNkHDrjRYM6-zMpyPJjnNWFhRfpwARoniwwJKELFTTayXPksjNlAhxpZFLsHLBValVWzulltRcLEFxMJbFmlZHCwdFq4)**2))

A165519558276941562 = np.vectorize(segment_length)


def spectrum_length(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44,AAAaAAAAAAaAAaAAAaAa):
    Y165519558276941563 = eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44[range((len(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44)-1))]
    zMpyPJjnNWFhRfpwARoniwwJKELFTTayXPksjNlAhxpZFLsHLBValVWzulltRcLEFxMJbFmlZHCwdFq4 = AAAaAAAAAAaAAaAAAaAa[range((len(AAAaAAAAAAaAAaAAAaAa)-1))]
    nqjDPlPKImakuPauEKMZBNJYmGPuRpYykevtNFymLGfjidskqvzNPufDnCpPKrWRsbOlugbxYSHOFNj5 = eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44[range(1,len(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44))]
    htRAsoxSTCFxiufxXZEzOphdxQujuWTZHTTelDdGSKqLrAAzNMHRemUjlYLnsvobgZTvYgNkHDrjRYM6 = AAAaAAAAAAaAAaAAAaAa[range(1,len(AAAaAAAAAAaAAaAAAaAa))]
    lIIIlll = A165519558276941562(Y165519558276941563,zMpyPJjnNWFhRfpwARoniwwJKELFTTayXPksjNlAhxpZFLsHLBValVWzulltRcLEFxMJbFmlZHCwdFq4,nqjDPlPKImakuPauEKMZBNJYmGPuRpYykevtNFymLGfjidskqvzNPufDnCpPKrWRsbOlugbxYSHOFNj5,htRAsoxSTCFxiufxXZEzOphdxQujuWTZHTTelDdGSKqLrAAzNMHRemUjlYLnsvobgZTvYgNkHDrjRYM6)
    AAAaaaaA = np.sum(lIIIlll)
    llIIlIlIl = np.cumsum(lIIIlll)
    return(AAAaaaaA,lIIIlll,llIIlIlIl) 
    
def segment_pt_coord(Y165519558276941563,zMpyPJjnNWFhRfpwARoniwwJKELFTTayXPksjNlAhxpZFLsHLBValVWzulltRcLEFxMJbFmlZHCwdFq4,nqjDPlPKImakuPauEKMZBNJYmGPuRpYykevtNFymLGfjidskqvzNPufDnCpPKrWRsbOlugbxYSHOFNj5,htRAsoxSTCFxiufxXZEzOphdxQujuWTZHTTelDdGSKqLrAAzNMHRemUjlYLnsvobgZTvYgNkHDrjRYM6,LaxXRcxVRJYrzhtRllSCcRMfYTfsDKJWdyFWZuiMkiEJntcaqrBKolNSDPKkanEYRUJxeDciVNsdxTV67,aaAaAaaAaAaAaaaAAaaAaaaaaaaAaaAaaaAAaAAAaAAaAaAAAAaAAAAAAAaaaaAAAAaA):
    llIlllIIlI = LaxXRcxVRJYrzhtRllSCcRMfYTfsDKJWdyFWZuiMkiEJntcaqrBKolNSDPKkanEYRUJxeDciVNsdxTV67/aaAaAaaAaAaAaaaAAaaAaaaaaaaAaaAaaaAAaAAAaAAaAaAAAAaAAAAAAAaaaaAAAAaA
    O1655195582774415311 = Y165519558276941563 + llIlllIIlI*(nqjDPlPKImakuPauEKMZBNJYmGPuRpYykevtNFymLGfjidskqvzNPufDnCpPKrWRsbOlugbxYSHOFNj5-Y165519558276941563)
    IllIlIIIlIII = zMpyPJjnNWFhRfpwARoniwwJKELFTTayXPksjNlAhxpZFLsHLBValVWzulltRcLEFxMJbFmlZHCwdFq4 + llIlllIIlI*(htRAsoxSTCFxiufxXZEzOphdxQujuWTZHTTelDdGSKqLrAAzNMHRemUjlYLnsvobgZTvYgNkHDrjRYM6-zMpyPJjnNWFhRfpwARoniwwJKELFTTayXPksjNlAhxpZFLsHLBValVWzulltRcLEFxMJbFmlZHCwdFq4)
    return(O1655195582774415311,IllIlIIIlIII)        

def interval_selection(ppppppppppppppppppppppppppppppppppppppppppppppppppppppppppp,CumVect):
    IlllIIllllIII = np.where(ppppppppppppppppppppppppppppppppppppppppppppppppppppppppppp<=CumVect) 
    h165519558277642114 = np.where(ppppppppppppppppppppppppppppppppppppppppppppppppppppppppppp>=CumVect)
    return(np.min(IlllIIllllIII),np.max(h165519558277642114))
    
def nearest_x(x_test,vx):
    aaaaAaaaaaaAaaa=0
    SIobuJcqJGenGHfoNDaIoyhajIWpXssScBqCijlesmXDlbBIXxGkbddyYallhEfFXHcjBTXyMhaxCZb16 = abs(x_test-vx[aaaaAaaaaaaAaaa])
    for i in range(1,len(vx)):
        CqRaPgNVdtfTGpOXVmGAduBKvXsqTqNbLIzvCimRhJuKSvVGWtfMKmJHsCZgunJToItoeRsWVcsHchE17 = abs(x_test-vx[i])
        if CqRaPgNVdtfTGpOXVmGAduBKvXsqTqNbLIzvCimRhJuKSvVGWtfMKmJHsCZgunJToItoeRsWVcsHchE17 < SIobuJcqJGenGHfoNDaIoyhajIWpXssScBqCijlesmXDlbBIXxGkbddyYallhEfFXHcjBTXyMhaxCZb16: 
            SIobuJcqJGenGHfoNDaIoyhajIWpXssScBqCijlesmXDlbBIXxGkbddyYallhEfFXHcjBTXyMhaxCZb16=CqRaPgNVdtfTGpOXVmGAduBKvXsqTqNbLIzvCimRhJuKSvVGWtfMKmJHsCZgunJToItoeRsWVcsHchE17
            aaaaAaaaaaaAaaa=i
    return(aaaaAaaaaaaAaaa)        


#####################
##    GENERATORS   ##
#####################
    # def fit_transform(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa=None, **fit_params):
    #     return super().fit_transform(O1655195582786395330, AAAaAAAAAAaAAaAAAaAa)
    
    # def fit(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa = None):
    #     return super().fit(O1655195582786395330, AAAaAAAAAAaAAaAAAaAa)

    # def transform(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa):
    #     return super().transform(O1655195582786395330,AAAaAAAAAAaAAaAAAaAa)
        


class Augmenter(TransformerMixin, BaseEstimator):
    
    def __init__(self, IIlIlIlllIlIIlIllllIll = 1):
        self.count = IIlIlIlllIlIIlIllllIll

    def fit_transform(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa=None, **fit_params):
        return self.transform(O1655195582786395330, AAAaAAAAAAaAAaAAAaAa)
    
    def fit(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa = None):
        return self

    def augment(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa):
        ntJJphlWQXuvOXouwVcvSMxXNyrDsNjclITYjzocQjJlPiXiFELryLdevGmojuPFWkzIvIwuNshqEqq26 = O1655195582786395330.copy()
        M27 = AAAaAAAAAAaAAaAAAaAa.copy()
        return ntJJphlWQXuvOXouwVcvSMxXNyrDsNjclITYjzocQjJlPiXiFELryLdevGmojuPFWkzIvIwuNshqEqq26, M27

    def transform(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa):
        self.init_size = len(O1655195582786395330)
        for i in range(len(O1655195582786395330)):
            for AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa in range(self.count):
                newX, T1655195582785416629 = self.augment(O1655195582786395330[i], AAAaAAAAAAaAAaAAAaAa[i])
                if isinstance(newX, np.ndarray):
                    O1655195582786395330 = np.vstack([O1655195582786395330, newX])
                    AAAaAAAAAAaAAaAAAaAa = np.vstack([AAAaAAAAAAaAAaAAAaAa, T1655195582785416629])
        return O1655195582786395330, AAAaAAAAAAaAAaAAAaAa
    
    def inverse_transform(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa):
        return O1655195582786395330[0:self.init_size], AAAaAAAAAAaAAaAAAaAa[0:self.init_size]
    
    def _more_tags(self):
        return {'allow_nan': False}
    
    
    
class SampleAugmentation(Augmenter):
    def augment(self, O1655195582786395330, AAAaAAAAAAaAAaAAAaAa):
        return None, None
    
class Rotate_Translate(Augmenter):
    def augment(self, spectrum, AAAaAAAAAAaAAaAAAaAa):
        """ rotate and translate signal """
        e32 = np.linspace(0, 1, len(spectrum))
        AAAaaaaaaaaAAaAaAAAaAaAAaAAAaaAAa = random.uniform(-2,2)
        A34 = random.uniform(-2,2)
        HhnIuwlQbRKXnURZHbsqPNtBVhYUAkJPaJxxbGjkaBynfyBmCUGALidROFGxxTjMgOcVIPkTTRJFvbQ35 = random.uniform(0,1)
        h165519558278939636 = random.uniform(0,np.max(spectrum)/3)
        jjlybTswCmTgroLPqKveIPChmHTTDAkgJGZJUmCimqDNuigIFOmTxDZnclIdtsBnfxNmJXzktGRnlty37 = AAAaaAaaAaAAaAaaaaaAAaAAAaAaaAaAaaAAAAaaAAAAaAAAaaAaaaaAa(e32,HhnIuwlQbRKXnURZHbsqPNtBVhYUAkJPaJxxbGjkaBynfyBmCUGALidROFGxxTjMgOcVIPkTTRJFvbQ35,h165519558278939636,A34,AAAaaaaaaaaAAaAaAAAaAaAAaAAAaaAAa)
        jjlybTswCmTgroLPqKveIPChmHTTDAkgJGZJUmCimqDNuigIFOmTxDZnclIdtsBnfxNmJXzktGRnlty37 = jjlybTswCmTgroLPqKveIPChmHTTDAkgJGZJUmCimqDNuigIFOmTxDZnclIdtsBnfxNmJXzktGRnlty37*np.std(spectrum)
        FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39 = spectrum + jjlybTswCmTgroLPqKveIPChmHTTDAkgJGZJUmCimqDNuigIFOmTxDZnclIdtsBnfxNmJXzktGRnlty37
        # FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39[FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39 < 0] = 0
        return np.array(FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39), AAAaAAAAAAaAAaAAAaAa
    
    

class Monotonous_Spline_Simplification(Augmenter):
    def augment(self, spectrum, AAAaAAAAAAaAAaAAAaAa):
        """ Select regularly spaced points along x_axis and adjust a s1655195582800395549 """
        YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY = len(spectrum)
        IIllIIIIlllIlIIIlIIlIIIlIIllIIllIIIlIIIIl = np.arange(0, YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY, 1)
        r42 = 60

        EPaQiuNmVILFLGdQNAVtnpAUyGYYtQgxHPtdrnTzTZeOhpQkNuGDqsKzdNEYolAZHmPnEVCINpMuAFU43 = np.unique(np.concatenate(([0],random.sample(range(YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY),r42),[YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY-1])))
        EPaQiuNmVILFLGdQNAVtnpAUyGYYtQgxHPtdrnTzTZeOhpQkNuGDqsKzdNEYolAZHmPnEVCINpMuAFU43.sort()
        eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 = IIllIIIIlllIlIIIlIIlIIIlIIllIIllIIIlIIIIl[EPaQiuNmVILFLGdQNAVtnpAUyGYYtQgxHPtdrnTzTZeOhpQkNuGDqsKzdNEYolAZHmPnEVCINpMuAFU43]
        AAAaAAAAAAaAAaAAAaAa = spectrum[EPaQiuNmVILFLGdQNAVtnpAUyGYYtQgxHPtdrnTzTZeOhpQkNuGDqsKzdNEYolAZHmPnEVCINpMuAFU43]
        XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa = interpolate.splrep(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44, AAAaAAAAAAaAAaAAAaAa, AAAaAAaAaaaAaaaaaaaaaaAaaaaaAaaaAaAaaaaAaaAAaAA=0, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa=3)
        s1655195582800395549 = interpolate.BSpline(XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa, E1655195582800395550=False)
        
        return s1655195582800395549(IIllIIIIlllIlIIIlIIlIIIlIIllIIllIIIlIIIIl), AAAaAAAAAAaAAaAAAaAa


class Dependent_Spline_Simplification(Augmenter):
    def augment(self, spectrum, AAAaAAAAAAaAAaAAAaAa):
        """ Select regularly spaced points ON the spectrum and adjust a s1655195582800395549 """
        YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY = len(spectrum)
        drCCgMSMjGtrEtuFrpgyEKcxKtDatDLEWprXusufjYOYzXwXmWIbHPHvRpYpToeSPXmcEYrwJhrJkww52 = np.linspace(0, np.max(spectrum), YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY)
        P53 = spectrum_length(drCCgMSMjGtrEtuFrpgyEKcxKtDatDLEWprXusufjYOYzXwXmWIbHPHvRpYpToeSPXmcEYrwJhrJkww52,spectrum)
        AaaAAaaaaaaaAaaaaAAaAaaAAaaaaAAaaAaAaaaAaaAAaaaaaaaAaA = 10
        IIlIlIlIIIlIlIIIIllIlIllIIlllllIllIllIIllIIllIIIIIIIIIl = []
        AaaaaaaAaAaaaAaaaaAaaAAAAAAAaaAaAaaAAAAaAaaAaaAAaaaaAaAA = []

        for AAAaAAaAaaaAaaaaaaaaaaAaaaaaAaaaAaAaaaaAaaAAaAA in range(1,AaaAAaaaaaaaAaaaaAAaAaaAAaaaaAAaaAaAaaaAaaAAaaaaaaaAaA):
            AAAaaAaaAaAAaAaaaaaAAaAAAaAaaAaAaaAAAAaaAAAAaAAAaaAaaaaAa = spectrum_length(drCCgMSMjGtrEtuFrpgyEKcxKtDatDLEWprXusufjYOYzXwXmWIbHPHvRpYpToeSPXmcEYrwJhrJkww52,spectrum)[0] / AaaAAaaaaaaaAaaaaAAaAaaAAaaaaAAaaAaAaaaAaaAAaaaaaaaAaA
            # aaaAaAAAAAaAAaaaaaaaAAaAaaAaAAaaaaAaAAaaaAAAAAAAaAAAaAAaAA = np.cumsum(np.repeat(AAAaaAaaAaAAaAaaaaaAAaAAAaAaaAaAaaAAAAaaAAAAaAAAaaAaaaaAa,AaaAAaaaaaaaAaaaaAAaAaaAAaaaaAAaaAaAaaaAaaAAaaaaaaaAaA))
            ppppppppppppppppppppppppppppppppppppppppppppppppppppppppppp = AAAaAAaAaaaAaaaaaaaaaaAaaaaaAaaaAaAaaaaAaaAAaAA*AAAaaAaaAaAAaAaaaaaAAaAAAaAaaAaAaaAAAAaaAAAAaAAAaaAaaaaAa
            H60 = P53[2]
            blfBMfpRVutopZioaggHzOIIbCqzViLnakKCHmpqvSELADwGAkOEbXzXvqLcvobYORNUOTkgIkTugwi61 = interval_selection(ppppppppppppppppppppppppppppppppppppppppppppppppppppppppppp,H60)
            IIIlIlIIlIIlIllllIlIllllIIlIIIlIIIlIIlIllIllIllIIIIIllIIllIlIl = segment_pt_coord(
                Y165519558276941563=drCCgMSMjGtrEtuFrpgyEKcxKtDatDLEWprXusufjYOYzXwXmWIbHPHvRpYpToeSPXmcEYrwJhrJkww52[blfBMfpRVutopZioaggHzOIIbCqzViLnakKCHmpqvSELADwGAkOEbXzXvqLcvobYORNUOTkgIkTugwi61[1]],
                zMpyPJjnNWFhRfpwARoniwwJKELFTTayXPksjNlAhxpZFLsHLBValVWzulltRcLEFxMJbFmlZHCwdFq4=spectrum[blfBMfpRVutopZioaggHzOIIbCqzViLnakKCHmpqvSELADwGAkOEbXzXvqLcvobYORNUOTkgIkTugwi61[1]],
                nqjDPlPKImakuPauEKMZBNJYmGPuRpYykevtNFymLGfjidskqvzNPufDnCpPKrWRsbOlugbxYSHOFNj5=drCCgMSMjGtrEtuFrpgyEKcxKtDatDLEWprXusufjYOYzXwXmWIbHPHvRpYpToeSPXmcEYrwJhrJkww52[blfBMfpRVutopZioaggHzOIIbCqzViLnakKCHmpqvSELADwGAkOEbXzXvqLcvobYORNUOTkgIkTugwi61[0]],
                htRAsoxSTCFxiufxXZEzOphdxQujuWTZHTTelDdGSKqLrAAzNMHRemUjlYLnsvobgZTvYgNkHDrjRYM6=spectrum[blfBMfpRVutopZioaggHzOIIbCqzViLnakKCHmpqvSELADwGAkOEbXzXvqLcvobYORNUOTkgIkTugwi61[0]],
                LaxXRcxVRJYrzhtRllSCcRMfYTfsDKJWdyFWZuiMkiEJntcaqrBKolNSDPKkanEYRUJxeDciVNsdxTV67=P53[1][blfBMfpRVutopZioaggHzOIIbCqzViLnakKCHmpqvSELADwGAkOEbXzXvqLcvobYORNUOTkgIkTugwi61[1]]%AAAaaAaaAaAAaAaaaaaAAaAAAaAaaAaAaaAAAAaaAAAAaAAAaaAaaaaAa,
                aaAaAaaAaAaAaaaAAaaAaaaaaaaAaaAaaaAAaAAAaAAaAaAAAAaAAAAAAAaaaaAAAAaA=P53[1][blfBMfpRVutopZioaggHzOIIbCqzViLnakKCHmpqvSELADwGAkOEbXzXvqLcvobYORNUOTkgIkTugwi61[1]]) 

            IIlIlIlIIIlIlIIIIllIlIllIIlllllIllIllIIllIIllIIIIIIIIIl.append(IIIlIlIIlIIlIllllIlIllllIIlIIIlIIIlIIlIllIllIllIIIIIllIIllIlIl[0])
            AaaaaaaAaAaaaAaaaaAaaAAAAAAAaaAaAaaAAAAaAaaAaaAAaaaaAaAA.append(IIIlIlIIlIIlIllllIlIllllIIlIIIlIIIlIIlIllIllIllIIIIIllIIllIlIl[1])
        
        eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 = np.array(IIlIlIlIIIlIlIIIIllIlIllIIlllllIllIllIIllIIllIIIIIIIIIl)
        eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 = np.concatenate(([0],eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44,[np.max(drCCgMSMjGtrEtuFrpgyEKcxKtDatDLEWprXusufjYOYzXwXmWIbHPHvRpYpToeSPXmcEYrwJhrJkww52)]))
        AAAaAAAAAAaAAaAAAaAa = np.array(AaaaaaaAaAaaaAaaaaAaaAAAAAAAaaAaAaaAAAAaAaaAaaAAaaaaAaAA)
        AAAaAAAAAAaAAaAAAaAa = np.concatenate(([spectrum[0]],AAAaAAAAAAaAAaAAAaAa,[spectrum[YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY-1]]))
        # print(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44)
        XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa = interpolate.splrep(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44, AAAaAAAAAAaAAaAAAaAa, AAAaAAaAaaaAaaaaaaaaaaAaaaaaAaaaAaAaaaaAaaAAaAA=0, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa=3)
        xmin, d1655195582825415876 = eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44.min(), eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44.max()
        rrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrr = np.linspace(xmin, d1655195582825415876, YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY)
        s1655195582800395549 = interpolate.BSpline(XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa, E1655195582800395550=False)

        return s1655195582800395549(rrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrr), AAAaAAAAAAaAAaAAAaAa

class Random_Spline_Addition(Augmenter):
    def augment(self, spectrum, AAAaAAAAAAaAAaAAAaAa):
        """ Add s1655195582800395549 noise on AAAaAAAAAAaAAaAAAaAa """
        YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY = len(spectrum)
        IIllIIIIlllIlIIIlIIlIIIlIIllIIllIIIlIIIIl = np.arange(0, YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY, 1)
        uuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuu = np.max(spectrum)/80
        K1655195582832396383 = uuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuu/2 
        lIIlIlIllIIIlIIlIIIIIIllllllIlIllIIIlIIllIIIIlIIllIIIlIlIIlIlllllIlIlllIIlllIIIIllII = random.uniform(-K1655195582832396383, K1655195582832396383)
        IlIlIlIlIlIIlIllIIlIIlIlllIlIllllllIIIlIIlIIIIIllllIllIIIIIlllIIIllIllllIllIIlllIIIll = -K1655195582832396383 + lIIlIlIllIIIlIIlIIIIIIllllllIlIllIIIlIIllIIIIlIIllIIIlIlIIlIlllllIlIlllIIlllIIIIllII
        aaaAaAaAaAAaaaaaAAAaAAAaaAaAAaaaAaaaAaaAaaAaAAaaaaAAAAAaaaAAAAaaaAaAaaAAaaAAaAaaAAAaaA = K1655195582832396383 + lIIlIlIllIIIlIIlIIIIIIllllllIlIllIIIlIIllIIIIlIIllIIIlIlIIlIlllllIlIlllIIlllIIIIllII

        IlIlllllIllIllIllllIlIIllllllllllllllllIIlIlIlIIIlIIIlIIlIlIIIlIlIllIIIlIIIIIIIlIlllIlI = 40
        QQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQ = np.linspace(0, YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY,IlIlllllIllIllIllllIlIIllllllllllllllllIIlIlIlIIIlIIIlIIlIlIIIlIlIllIIIlIIIIIIIlIlllIlI)
        KazRmvxThviMXHzMAqtaCfNaIiJUSTwdxDTZwUcItwgIdxzxLlbJxJJYZGlSjHTUcueqFbTQrnttGHp89 = [random.uniform(IlIlIlIlIlIIlIllIIlIIlIlllIlIllllllIIIlIIlIIIIIllllIllIIIIIlllIIIllIllllIllIIlllIIIll,aaaAaAaAaAAaaaaaAAAaAAAaaAaAAaaaAaaaAaaAaaAaAAaaaaAAAAAaaaAAAAaaaAaAaaAAaaAAaAaaAAAaaA) for i in range(IlIlllllIllIllIllllIlIIllllllllllllllllIIlIlIlIIIlIIIlIIlIlIIIlIlIllIIIlIIIIIIIlIlllIlI)]

        eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 = np.asarray(QQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQ)
        eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44.sort()
        AAAaAAAAAAaAAaAAAaAa = np.asarray(KazRmvxThviMXHzMAqtaCfNaIiJUSTwdxDTZwUcItwgIdxzxLlbJxJJYZGlSjHTUcueqFbTQrnttGHp89)
        XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa = interpolate.splrep(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44, AAAaAAAAAAaAAaAAAaAa, AAAaAAaAaaaAaaaaaaaaaaAaaaaaAaaaAaAaaaaAaaAAaAA=0, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa=3)

        s1655195582800395549 = interpolate.BSpline(XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa, E1655195582800395550=False)
        jjlybTswCmTgroLPqKveIPChmHTTDAkgJGZJUmCimqDNuigIFOmTxDZnclIdtsBnfxNmJXzktGRnlty37 = s1655195582800395549(IIllIIIIlllIlIIIlIIlIIIlIIllIIllIIIlIIIIl)
        FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39 = spectrum + jjlybTswCmTgroLPqKveIPChmHTTDAkgJGZJUmCimqDNuigIFOmTxDZnclIdtsBnfxNmJXzktGRnlty37
        # FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39[FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39 < 0] = 0
        return np.array(FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39), AAAaAAAAAAaAAaAAAaAa

class Random_Y_Shift(Augmenter):
    def augment(self, spectrum, AAAaAAAAAAaAAaAAAaAa):
        """ Additive J109 on AAAaAAAAAAaAAaAAAaAa """
        v99 = np.max(spectrum) - np.min(spectrum)
        FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39 = spectrum + random.uniform(-v99,v99) / 20
        return FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39, AAAaAAAAAAaAAaAAAaAa

class Random_Multiplicative_Shift(Augmenter):
    def augment(self, spectrum, AAAaAAAAAAaAAaAAAaAa):
        """ Multiplicative J109 on AAAaAAAAAAaAAaAAAaAa """
        FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39 = spectrum * random.uniform (-0.05, 0.05)
        return FBEVsLJqmFKicZRBfZDZwsHabvhaymEIjfjUbodoDeIxQCNGdvibwhJitlrHkZDEcedANCqJXVTxSmr39, AAAaAAAAAAaAAaAAAaAa


class Random_X_Spline_Deformation(Augmenter):
    def augment(self, spectrum, AAAaAAAAAAaAAaAAAaAa):
        """ Random modification of eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 based on subsampled s1655195582800395549 """
        eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 = np.arange(0, len(spectrum), 1)
        XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa = interpolate.splrep(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44, spectrum, AAAaAAaAaaaAaaaaaaaaaaAaaaaaAaaaAaAaaaaAaaAAaAA=0, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa=3)

        AAAaaAAAaaaAaAaAaaAAaaaaAaAaAaaAaAAaaaaAaAaAaAAAAaAaaAaAAAAAaAAAaAaAAAaaaaAAaaAAaaAaAAAAaAaaaAaaaAAaAaaaaa = int(np.around(len(XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110)/20))
        ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo = np.linspace(np.min(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44), np.max(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44), AAAaaAAAaaaAaAaAaaAAaaaaAaAaAaaAaAAaaaaAaAaAaAAAAaAaaAaAAAAAaAAAaAaAAAaaaaAAaaAAaaAaAAAAaAaaaAaaaAAaAaaaaa)
        U108 = np.random.uniform(-10,10,AAAaaAAAaaaAaAaAaaAAaaaaAaAaAaaAaAAaaaaAaAaAaAAAAaAaaAaAAAAAaAAAaAaAAAaaaaAAaaAAaaAaAAAAaAaaaAaaaAAaAaaaaa)
        J109 = np.interp(XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo, U108)
        XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110 = XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110 + J109
        s1655195582800395549 = interpolate.BSpline(XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa, E1655195582800395550=True)
        return s1655195582800395549(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44), AAAaAAAAAAaAAaAAAaAa

class Random_X_Spline_Shift(Augmenter):
    def augment(self, spectrum, AAAaAAAAAAaAAaAAAaAa):
        """ Add s1655195582800395549 based eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 shift """
        eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 = np.arange(0, len(spectrum), 1)
        J109 = random.uniform(-10,10)
        eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 = eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44 + J109
        XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa = interpolate.splrep(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44, spectrum, AAAaAAaAaaaAaaaaaaaaaaAaaaaaAaaaAaAaaaaAaaAAaAA=0, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa=3)
        s1655195582800395549 = interpolate.BSpline(XMuTyqrXIEeoNSHsLGiwRmNlPqixwlGyAWmPoCPKFApoHAuIpdeslLFpmQmRZfXdhcOPGdLFgdxzmBv110, c, AaAAaaaAAAAaAAaaAAAaAAaAAaaaAaAAAAaaAAaaaaaaAa, E1655195582800395550=False)
        return s1655195582800395549(eeDkvHgzXzwPYyFUSmJmbupLUjEctUZReoIqIAqvcjwJgLNvllsqLYJwAyAOChgVnQZUPvkLuVuBqbS44), AAAaAAAAAAaAAaAAAaAa


n165519558287339451 = "zQcmnkPksfKTwjbnfuwGAFQLxziHKdoroghnKWiFXPDmbAyEszUmoOzlJeVLgWDCZYvooCPXiDDOBWM"
aAA = "cWrbvCjihpFNuBpUazilYbUBWfHqweKUZRszDexoQsvvBXzgqyAoKvNbFLvBFRAgYUGvFAXZduIbNSu"
IIlll = 199
b165519558287339457 = "EolcbPVFOXSPzwsYnxRTpUVzrAgcTmOqKJygPpSylbZEuvHoxIvBfXTImesEdsDMkmwtPuLBJvnCrnu"
kkkkkkkkk = 520
wwwwwwwwwww = "EDsstFKjSftEgLLSJrBEcSsUVddcirVgHeqfyYJTHhIQgcmyYiJeezuyGRbOdtLkAaYorHjLZTMcocm"
AaAaaAaAaaAAA = "mMJiaFGWRTwqHzwPyLlfflqZWOejRgkZXsXSQqlOcjtyrtlwsuUxqSuXFjIoMnuJjceneTCTSaNXMhn"
xxxxxxxxxxxxxxx = "ZSlYNNaTrCQOyauIOIKRwCZZpihzmrgDsnIICzCkvhrZirYmTLFGNNZLbJkYlBzlAPxmhwsbPgWjrfG"
epQEUZYFMJAfBfoJMPrNuvDWvVRCpFrJRByOFFnQtYMlrLRnVzucUEsiXBSWtSqoZiphqpQFncaqKTs17 = 327
AaaaAaaaaAaaAaaAaAa = 431
q1655195582874394721 = "lKgAhcNsBMvWkwrsHxzKbpLQRRBLQoXrPCBAuigpfTfrtublwMTuuTAPSjIzzuNGFKxlFKUYmKcjOaC"
s23 = "EXxAcHnQpfQzqyKBnJLeTDPlVOzanikzBpuzQvuBOsVsahJvavDqUPwlkbvZTncwYjleuOQQaVFJpTZ"
V1655195582874394725 = 103
v27 = "qPhvhbxOIHiulRdCAIduKPYwuDDCxolmDCDojXReQtUXZMfIvCvNuAdmvRobMDMIWFptEmsuvAenhxA"
jgXQWqUPRqcOzdVJEINrOuVXUInmQZvRprnxzLDbUqitUCToLEirzETGQAaOaWfSiszIyFuWOfDnRPQ29 = 659
lIlIIIlllIIIlIIIllIIIlIlIlllIIl = "rgDgZdgtUQevTTPcuZlNSKYnyUlWhHPtLrehSqOsevwBJXcOotNbXzZoYkCPSwAWcxfRaSqGmaqQatJ"
AAaAaAaAaaAaAaAaAAAAAaAaAAAAaAAAA = 114
M165519558287539535 = "ZlOyGZBDdRifAGlPWasWdrpkIWfNYiLknURXXkVgdEtFiNtGtZiayIzkHKHtYjgGsGIByWTevSJNmvf"
d37 = 196
Z39 = "nBErKUsdghDhrOMnosciutBJvlAwUdgeiDgWzwrRmuUhxxnoaWauVoXfymWJzoxYaloFiMUUcqzckiD"
M41 = 288
KfgxjqJFLsGOidBFWejRorgCiTGpayLlSAXRcZPmrIOkaIXQtwrVOgXiEajGjLgtFBtIUBxNSIFHNux43 = "uyVsoDiaNFfSwHKVppAOJJHHCGkuarRjeyNOycbUsOFoVbutGWphURUtfJaoxtRrBvgPWppNofPcwZW"
PJEcxhbpWalEAyDPWePCothgytPmjxaMnBnHjMDATXakJunJfkRIikcBLTRBpjtxPmpUbQUWJsgWxzB45 = "MpgGgYbOIMFiqSqCVSeciZNIulJOPyfASzOkfgMVYFdPWMWFxhqnzjjAhTLxIoSGWqLpTVDuShCGMez"
DMFYiGGSSlFlDRfJKIyGwZkQpCsRwmnFnSiWJfBHKrACTbKfItVRuMETOiDnZoRwmYYqXpFyfJKGENi47 = 203
aAAAaaaaAAAAAaAAaAaAaaAaaAAAAaAAAaaaaaaAaaaAaaaAA = 391
l1655195582876416751 = 314
llllIllIIIIIlllIIlllllllIlIlIllIlIllIIIlIlIllIIIIIlII = "rNcZJjWUmzuvmXswWYSNzUFKoNouiWjqGlbcXnjFITKAzlSBHcFelziviZwxJvkfZkWoVUcExzlTrIS"
aaAAAAaAAAAaAaaaAAaaAaaaaaAAaAaAaaaaaAaaaAAAaAAAaaAaAAa = 214
aaAaaAaaaAaaaaaaaaaaAaAaaaaAaaaaAAAaAaAAaAAAaaAAAaaaaaaAA = 444
GetOqldQPXbxiCSstGwHrbDqomLASdeyYOCJhmPiLGZQBTpojdUoctUKOSlyquSzHEZlThRogqmXjxF59 = 271
y61 = 606
kFRJXFrvxflTHfxRVyOubTuYKLdUuxKrelJWwLhKeNAjwRqundYrMQWPQfARChhpgYlfsMfigAYJiGH63 = 427
c65 = 59
HwiQtqufunQbvVtgHThALeuGHjxdUdhPiTEnykugUsNLmoycFXTAIDtMGHGjaaTBOtMtsLelyRRvyVD67 = "gaOdNSHMNCQnhldPRUCBDTlXdsQBHEbUegxiaFHIJdqJCZgCnUwYAMbDXnlNxMimimpbaymBtqSZtXT"
fffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff = "aroinnVlzDolHMFpDfZZGmxqAmPerIBtzBlJYOarxQrZlVaAbRvSMXPsSpOIvvDLijzgqGDFdxGnLlj"
vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv = "pXZexsKCjimgXUqLvpQIWVKfeonvANoYDKTwYCBVGlbBLkRhpwOrGwlicJmOBHvtDNlqBtXJroqVKEz"
aaaaaaaAAaaaAaAAaaaaaAaAaaAAaaaAaaaaaaAAAAaAAAAAAAaAAAAaAAAaaAaaaaAaaAAaA = 505
OOGXfPzuTuyMljMDzxMQQLEeSDSLnkLnICImgdTYYwrnDiyhTXFHADpxvQxmNbyUgMXqeVjjuXEfegt75 = "IDtMalZUHYpvSeKvYWRTiKezcejlVvdptmfBsqxsTdQrTHDtEsLzYmyoSHTbQBTfdyDrcBKQRKifWlw"
E1655195582878416377 = 95
dWdIQoWAKQRszSnGVLUkvgddwJLwTqFdnfVmJvossekjQwBBmODtTcStEpiftwfAsDMTCFbspqwBRXZ79 = 268
AAAAAAAaAaaAaAaAaAAaAAaaAAaAaAaaAAaaAAAaaaaAaAAAAaaAaaAaaAaAAaAaAaaAAaAAAaAaAAaAA = 459
P83 = 292
lIIlIIIIIIlllIIIIIlllllIIIIIlIlIlIlIllIIIIIlllIlIlIlIIllIIIIIlIIIllIllIIllllIIIIllIll = "HJoLTlsBBehbGBBIXbHwrENaGJKtWvqvWlWnwbIqJydbYIjXfcqNvPxoVRmSmoJmhRapmeCwRnHjefU"
ttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt = "xZxkYosiKaPOLZBQzDRXvrpmIbxsLMJEhNWSQzeHRFguJWLoFsergrBOhRjFHFWDLPIamNbZAkwaKKZ"
aAAAaAaaaaaAAaAaAaaaAaaaAaaaAAAAAAAAaAaaaAaAAAaAAAAAaaaaAaAAAaaAaAaAAAaAAaAaAAAAAAAaaaaaa = "MuKZmFcgQuYzWFRRmTenzEcmJtEbLZsiHqNQdpLbJYtletUSlXuDZNLnyiKViIqTShiBXzCznrDfQsz"
sFetEkkJIviAvnMrFdGeoCDaxuHegjSZeMUGREITeMqNNHOGYsXPdwyAKloqNQnoKWkMSBDFRqhiXgB91 = 448
h1655195582880395493 = "rCzrVDQqSEXZFTPkgJXUVBCbIFColyRIlDFToIfpjWfvJUgiogcswyIiiQnQadmytTVtWgjLaabCcDB"
bteCOliAwHgVqsXfKvLmdAMdsxAWimUWlIGNrqTBwraFNdwyxISqYoxWQyCFOMigMIczuMbTAgzWlPA95 = "IIxiNaeLLrZSocaDaIfZImaxCDagufhsTouzoKNVDjwcpbdeCgFFNDEeyebGLzBcHPZRNcMMGtPeRNI"
DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD = 375
jHduhMBktieJgHSVQINlHUHcqJhwONEFBLzFWFgeQyhJAifUpZefZSKuWgpoPVmUMlxpEqxilshFcnz99 = "nlYdxunoCsOQFZdqVUgXWQgYFLhJIakAoJkltrAGhbPNAERoVSnqlzJcdykYuXdWukXrrUPhBvzovRd"
z16551955828803954101 = "xujCapsCFbnmaZzNIGvUIaWypytAlFsLHDRYtGCQvADGZYSPTlRWlMaxgtojZnmOGuyDFNdbBRoplyA"


IcplUGjcJYowIkcioDMUuNPTLmZftuFTPikmknQAafCSFlFhjDGCIKNkyfvrrDHZxyGSNIFGNWUGUYh224 = "FnpPncuLZIRvHRueXOFolVdHxQSfYVIJVpSHefBbxNaEAwCCFpdnrtKRuAgkFprAkNIOobKerlJsnJc"
W222 = 846
AAaaaAaAAaaAaAAAAAAAaaaAAAaAAAaAAaaaaaaaAaAAaAaAaaaAaAaaAAAAaaaaaAAaAAaAaaAaAAAAaaAAAAAAAAAaAAaaAAaAaaAAAaAaaAaAaaAaAaAAaAaAAaAAaaAaaAaaAAAAAAAaAAaAAAAAAaaAaAaAaAaAaaaaAaAaaAaAAaaaaAAaAAAaAaAaAAAAAAaaaaAAaAAAAAaAaaAaAAaA = 314
aaaAAaAaaaAaAAAAaAAAAAAaaAAAAaAaAAaaaAaaAAAAaaAaAaAaAAaaAaAaaaAAaaaaAaaaAAAaaAAaaAAAAAaaAAaaAAAAaAaaaaaaAaAaaaaaaAaAAAAAAAaaaaaaAAAaaaaAAaAAaAAAAaaaaAAaAAaAAaAaaaaaAAAaAAAaAaAAaaAaAAaAaaAAAAaAAaaAAAaaaAAaAAAAAaAaAAaAaa = 305
yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy = 440
iiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii = "QCwfFBalJiMZExQeGdfPibkpZAkyoAgvvUHpUAnyiGJsKvJjsuIXOaERLjmoBPlVUJFbNQmMkfyaHjP"
O212 = 214
qsvQhArQwbXMaeerCXuAsvoFABJXghnUjfxUcdAWVuYShFlePDGHPVMIdnXmwkLcYiAKyBbCrEFhZUP210 = "tDxmuyDsqevTqZIzZHtYUXlxyPixptBDPWmrlgKepRFXEqOSNpbiYZUBiYTqtvZIiQTbNgovlKHUXLV"
lIlIIlllIIIIIIlIlllIIIIlIllllllIllIIllIllIIIIIllIllllIIllIlIIIllIIIlllIlIlIlllIIIIIlIlIIllIllIllIlIllIllIIIllIlIIIIIllIllIIIllIIlIllIIIlIlIIIIIIIIllIIIllllIIIIllIllllIIIIlllIIlllIIlIlllllllIIllIIIlllIIIIIIllI = 755
BXeaFKzYEwcnLxZhudrxVVGAfNlKSelvckepAxiTrmGgkJhPnbXlLQPwAfMjkQVHyTPjsQdIccGRWAn206 = 369
lllllIllIllIIIIlIllllIllIIIlllIlllllllIlIlIlIIlllIIlIlIllIIIIIIlllllllllIIIIIlIlIlIlllllIllIlIlIIlIlIlIlIllIlIlIllIlIlIllIIlIIllllIIIIIIIlIlIllIIlIlIlllIlllIIllIIIIllIlIlIIIIIIlIlIIllIlIIIIlIllIlllIIIIIlI = "VtBEYrsJyTjDotTIitkuzOwCMQNIyvSEaFzOVJQfwzedAiXfSLpydnCWEqCXhAwUBZzpPAGcOysbLgc"
IIIlllIIlllllIIIIlIlIlIIIlIIIllIllIIIIIIIIIIlIIIIlIllIlIIlIllIlIIllIIlIIIlIlIIlllllIIlllllllllIIIlIIIIIlIIIIlIllIIIIllIIlIlIlIIllIIlIllllIlIIlllIIlIlIlIIlIlIIlIIllIllIllllIIIlIIlIlIllIlIIlIllIlllllIIlll = 867
M1655195574046259200 = 316
lllIlIIIIllIIIllIIIIlllIIllIIlllIlllIIlIIlIIIlIIIlllIlIllllIlIlIIlIlIlllIlIIlIIlIlIlIIlIIllIIIIIllIIIIlIIlIIlIllIllIlIlllIlllllllllIIlIIIlIllIlIIlIlIlIIIIIIIIllIllIlIlIIIlIlIlIIIIIlIIlIlIllllIlIIllI = 169
bDGIaSpvNuoOpNQDrsUflXxYrMgdIEgypKEXaiPRaDGXBKMFytZiiAgDwfcldzbPLgCvlYpnjeLxkOd196 = "PfZjTVHCruNztOzTkglujnPZMIKYnfQwAhejwNZBwivCtclShwDapKTkpzwdlGgeHDjzpTcrbGjMOHU"
AAaAaAaaaAaAAAaaAAaAaAaaAaAaaAAaaAaaaaAaAAaAaaaAAAAaaAaAaaAaaAAAaAAaAAaaaaaaaAAAAaAAaAAAAAAAAaaaAAAaaAAAaAaAaAAAAAaaAAAaAAAaAAaaaaAaaAaAaaAaaAAAAAaaAaaaaaAAaAAAAAAaAaaAaaAAaaaAaAaaAaAaaAAaaAaaaA = "AGYyUdcKMVCsGFoRiPwWuIgIydmxqvDmfdowftzlhmvGsBQVSAHOYCdAbnmvnlhsOUdwJnohdOHFxll"
VeOTBfRfVMxGevddkjoOXEgwdxdvGMVaMNwqRQWonrbXFyVnHQBbtejXpFXkhqawsmxHkOtbeUkFrwq192 = 328
IllllIIlIIlIIllllIIllllIIlllIIIIllllllIlIIIIlIIIIIlIIlIllllIlIlIIlIIIIllllIIllIlIlIIllIIlIllIIIIIlIllIllIlIIlIllllllllIllIlllIIllllIlllIllIIIIIIlIIIlllllllIllllllllIlIlIIlIIllIlIIlllIlIlIIIl = 383
aJkeHsaJhqKiPBYToOazwpPpnzImiYRqGiINWLzYFZPEhxhzWuDQDSrvnzaoFFuhwnUIWVPGbuQRLyZ188 = 549
W186 = "IegxyeftAaFEmXJBDuHAlWZptfudoZiGzPKpfzCxYQinDmOIlXowLUiRWYSvuLhQWCnHYpixoievltF"
b1655195574044286184 = "lNnptZvYnOqRFlUMdlBWMeTcradgYSucRDoUhSDRsZkVxCwZGmLPxTQrciVFSewHOianShRJInjMICB"
c16551955740432634182 = "qWOJqGFVsmkECUgWJYoxZPQoSgYCELxSvlCYKnlhVhMAftQDUxhwEeSeJGZDuZTskpTjcyzjpGKoiTa"
z16551955740432634180 = "ogJWFAMGOESNMrrQiLeWLNuJultkJkKXTdgqklajBVsUEDulCRcSNBCNjHcCsNrCJwCfCohYvXkMnvy"
hTqZnUgSvsEBvMMMZAoieVbhCpxdkSgUQRWODSAolKeTzPPaofvqbVnFSUpBjpYHwByCcLIMbGXPAia178 = "RZAGieicQdeqJLylCSBfRvgBTJyHgrVjoDUHDeYULTSFLkKYsxgZgEbnUocWSvCsByNiMZtQrfnKRuh"
lIIlIllIIIlIIlIIIIIIlllllIIIIIIIlIIIIIllIlIlIIIlIIlIIIllIllIIllllIIIlIllllIIIIIIIIllIllllllIlIIlllIIllllIIIIlIIIlIIIllIllllIIlIllIlllllIIIlIIllllIIIIlIlIIIlIIllllIIIIIllIlIIlll = "yArLHVsxxVErpTuNXDNZHVXtXxfbrvUQKSQGWqNzsfkPLIcKxDkCwUnrsoeRcSxBZlIlnROtudCSMxk"
U16551955740422573174 = 207
t172 = 662
VghxAgSvKsoQTQSrtAMdOPwFXYxKVyVhYVzZVMlernlpUxleHscGBASvIYqjpDtlfAifqZWIycBngjZ170 = "HxdlkyIdrAGQGGSogeayUeBRRjgmJLhCVZHpMRBZRgcrhUaRgtIrxbGCaIGzjRBQwDufvLstfAoEJJR"
E16551955740422573168 = "xXWwJThpxCdBMChBbZhbUZpcQBrgdKiAlXkTAMMBTNOrGvlDupgfVNAbHeqygOEQJMYZnVnrcIBSWnv"
IIlIlllIllIlIlIlIIIIIlllIlIIIIIIIlIllIlIlllllIllIIIIlIIIlIIlIIIlIIIIIIlIllIlIIlIIIllIIIIIlIIlIlIlIIIlIIIlIIIIlIllIIlIIIlIlIIlIIIlIllIIlllIlIlIIlIlIlIllllIllIlllIIlIIl = 585
i164 = 451
aaAaAAaAAAAAaaaAaaAAAAaAAaaaaAaaAAAaaAaAAAAAaAAAaAaaaAAaAaaaAaAaAAAAAaAaAAAAAaAaAaaaaaaaAaAaAaAaAaAAAAaAaAAAAaaAaAAAAAaaAaaAaAaAaAaaaAaaaaAaaAAaAaAaAaAaAaaAaaaaAa = "ZyeZBxNtSTIwtAyZsAozMckbHrFdUwDMyWEDQPneDeaSXhdbvabntRseNaBkCSSGTvRkuNUMrVmPZTM"
i160 = "HWkihceGOjnoFUCVzdtoSizsesFKqtOyeyOrpDtucKkgrYjSJisMOHCloecYEpmVLsivmktmkxgyudQ"
fNzuDuxaeLbYdMSPRlQLprkdxcHnhQUCQIMkDUCRqPrAXKQLUMosDBxFPNuATOJiPDCieIqRXBPKSLS158 = 379
IIlIlIIlIIIlllIlIIllIlIIIlllllIIIlIlllllIlIllIllIIIlIIIIllIllIllIllIIIIllIlllIIlIllIIllIllIIlIlllIIllIIlIlIIIIlllIlllIIIIIllIlllIlIllllIlllIIlllIIllIlIIlIIl = 370
d154 = 492
F152 = "uabRDNMAXRwSxgKRiHSKPjSEinAZkIAAOoqFEKSpXsVvhQDEmuodjNugVuDooSxcATAGiHhoeWFlsqX"
llIIIlIIllllllllIlIllIlIIIlIIlIllIIIIIlIIIIlIIIIlllIlIIlllIlIIIllIlIlIlIlllIlllllllIlllIllIIlllIlllIlIIlIlIlIlllllIlIllIIlIIllIIIIIlIlIlIlIlIlIlllIIlI = "FmxXULsPOssXcjjvvRcSigfpBZwqqPelVXworYojqQdGpdXhEDoxuIPfmfxwMPPYMoAtpVEpjJTODQp"
EBSUEPNqhDpAhhPZzVbPimIgdWLablJjzfwpDZxFybusYFqStoAJoRPgZJBjyjIxxDtMoXSeBAunTvy148 = 288
YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY = 511
vJrAbEfXhHERPdaMYlQIYexRBQEKYglVMVJchXRdxEDIAUpKrnRbRiuCXQnNTQVZOLxBSQKhTnQPTof144 = "IEegjnhfBhzdILaCeAwCtjWlIbcUNQgbBDVOrSkroQBWFgCWkhascUWcpCmabEnsiotjibMBUCAeJnw"
Q142 = 669
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX = "lGWxxYNfFkIqEewLvKwrFfHnpusyjLOWIGziLHTrZLzBGkGMCFNGDRnaHfqNYxfuwaLQfrAmAzPzEzy"
zGSAyExamtgERfXjYlqWpRSzjPtgIYyKnJIxhXapzBZhwzGpoJrKpIgCnlXZKNLBsyqLoGLvpPQdSRL138 = 898
AaAAaAAaAAAaaAAaAAaAAaAAAAaAAaAAAaAaaAAaaaaaaAaAAaAAAaaAAAAAaAaAAaaaAAAAaaAaaAaaaAAAAAAaAAaaAaAaAAaaaaAaAAAAaAaaAAaAaAAaAAAaaaaAAaaaaaAA = 780
a1655195574038284134 = 148
IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII = "JbmnczJCccuiOsLDBLwevBaJrtBwDcjdbuRVqMkckwwEiBKiPbSrNvEJPniphbhKWBYVnvOZicOpNZE"
DwNDkjwYtcELPvlHFLCUeQQmDjLuzXKmHsSqpmXnyZBskhKIUTSNdAWOVaQDSgFRcHhZISwTcNFmUIE130 = "CNZenuNDMVbccjLPCesSjnkZDOKjqcWKLCxEeoNdwwMGOsJKhCbQrCvRTRtpFtiMuhhWDlMJefYSuXy"
N16551955740372577128 = "FCZGBDdspwGaWwsgjMFnQnPJhEjEdVTQVQZWXtlsnplAzsBAvvUwBMgvOTdHNyRBlyvjjMSspLJlsFs"
IlIlIlllIIlIlllIllIIlIIIllllllIlIIlllllIllIlllIlIlIlIlllIlIIIIlIllllIlIllIlIIllllIIlIIlIIlllIIIIllllIlIIIllllIllllIIIIIIlIlIlI = 169
A16551955740372577124 = "orzAvhEVRYXZPLhugAxUtxevAJVFaZbVrOksfYzXOzAPjhnUkLyKLmVUqbtvLoiYBTleOvYQjacTHFu"
aAaaaaAaAAAAAaaaAAaAaAAaAAAaaAAaaAAAaaAAaAAAAaAAAaaAaaAaAaaAaaaAAAaaaAaaAAAAaAAAaAaAaaAAaAAaaaAAaaaAAAaAAAAAaAAAAaaaaaAaaA = "mdcUDuBwAsJvRZgDEHxGJtpWguBNCDeKFbAhDdwvsTnSBBrCrKiFPKxZvrXYeNOjLhRmPDngKIqfGMl"
d1655195574036285120 = 426
IIlIIllIIlllllllIlIllIIlIIlIIIlIIIIIllIIllIlIlIIIIlIllllllIIlIlIlIIllIllIllllIIlIIlllIlIlIlIIlIlIIIlIIIIllIIllIIlIlllI = "dwBDxPweDjsIPniUbBNDSiKoRvQPXnWJzKYsReBHRXYPWvdTyoypwhVyEEiVXPmkaMuSLxHEQlOzDNl"
g1655195574036285116 = 626
lIlllllIIIllllIlllIIllIIIIlIlIIllIllIIIIIIlIllIIIlIIlIIIlllIlIllIllllIllIIIIIIIIlIIIlIllIIIllIIIlIIllIlIlllIllllII = "KUeCjwhnaRmjnjPUHDMEWVbcWDsFGBxSWvgxytElCQfBhtUrcSPCuGicDOjujdrRFTKGwbORKgWvDJV"
u16551955740352604112 = "WkVmEsVDdxfvCiZonzLFvnvzPNrZxSlxIKQlIscxCJxvdLrMaBqVbbdFAGxyxsYRQSIWnuIkDiVscYp"
aaaaaAAaaaAaaaAAaAaaaaaAAaAaAAAaaAAaAaAaaaAaaaAAAaaAaaaAAAaAAAaaaaAAAaaaAAaAAaaAAAaaAaAaAAaaAAAaaaaaaAaaaaaaAA = 225
X16551955740352604108 = "ZyOTSQJzPaDWvTGUtXnfLPveJgytRiGoZFYIvkpKohahCSjqeAIUCHxkGjSDxainKKmOjcnzKkwpabJ"
PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP = "ZEDRtPljneHdRsHMVRVfAUarlniHeCccOBeZjBrVaciTcjHYzIctNSeSwgLrNEcVKxXTinzBatKgzTu"
IllIIllllllIIIlIIllllIIIllIIllIIIllIIIIlllIlIlllllllllIIlIIIIllllIlIllIllIIlllIlIIlIllllIIlIIllIlIIlIlII = 631
yoBOSOLXLzXvKcgVuCiDFsgqEWtfiYwTUtemGVnIOgoweMSmaXSIDNAQCMftBNzImvwnJnMkOBRrrRx102 = "zEOsXgIKHTNfOsgcwhlOUKtXbiMwlNEWxfMinnInGEtNmoVKrviwEeposIGPnqyQIZucMcwHeZSNyKn"
s100 = 720
llIIlllIIIIllIIIlIIIIIIIIllIIllIlIIIlIIIlllIIlIIlIIIlIIIIlIIllIlIllIlIIlIlIIIIllIIIlIllIlllIIllllI = "DXHgLIJZfuVIfLVBruDhvMhuYhHzDvzbTRFLiMjxyVIzlQEtDKrZVpuapddVYqNjUkOBSEcFfPDkdCs"
QtfKBFJMuHfPURNVuIWNVoCAqEmrAHXhrybxWwTlkbLnqOrLpimcSMwXfaMMHrBjHxKsWddpMpBLQur96 = 401
u165519557403325994 = 533
UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU = "FVjQgmKJKqrvksJSeGtUShRnZHfTyGEUoiANtBUuPMsZadsprtJiaDUAseieHbnIlGvbTceLicZvkbk"
z90 = 272
llllIIllIIllIllllIIIIlIIIllllIlllIIIllIIlIllIIlIIIllllllIIlIlIIllIlllIIIIIlIIlIlIIIlIlII = 297
W86 = "hTDqdbZgXFoLAFhIihkgoNmrKzDuaxLWvDTuWicLLYpvRwBXobqbjcbGxcOOjyrOkVboslaWWoEbfaO"
z165519557403325984 = "OTIEwNjJNdyIVNBWSMhlJmfGdlSYPDfVrYPVKjoFWJnPptzLwZoZRarixeAlKgySKjmBnuxRZgFbnul"
M1655195574032256682 = 417
lIlllIIIlIIIlllIlIIlllIIlIIllIlIlIllIlllllIIIllIIIlllIlIlIIIllIlIIIllIlIIlIllIII = 330
gggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggg = 371
F1655195574032256676 = "wzTdRANXNdVxpymJJyMpXeVXndVIAXlXleFIixxeGOSSYdIwzjttTlMsCXGbQXNDkEtstCFUwtvhQMk"
x74 = "icrJdmXQEnBvhHFuEoCtuqdwfPuDzxjnTsuLQqdzVKvlxXknmdQIVBpPUkbNSRiwRDCkdFcSgrxoZvx"
lIllllIllIIIIIIIIIIlIIIlIIlIlIlIIlIllIIlllIlIllIlIlIIIllllIlllllIIlIIlll = "vkqdhJfBlyuSzAldzaHVQppOzhXOQjiScHfgSmRfhITRbdQegYKIpVtRBGarQEPfODjCOWTuLlFbdCJ"
joeOenbZALyKXSMFZMQcsbvGGwpUkrozyAWpDAhoaKMkeUZErFFEQzpvfDglxOxKXFGjEmuutEHoHCI70 = "GsfOXJeJaRZUNSzftuiqorzzjpvPCslSEbYUmNmymjSuibNajWfvtjpmATpQAyqUKFqdykMrUDTWtSE"
u68 = "VRbUgbbxlHxKrybWWNFrrVKAjYDywbTalKWsTqZNRtiaRPZGfuDihRlqechqOOkXbuizMSzpQbYazuF"
Q66 = 322
d1655195574031259564 = "AVeMOHsfmTvIjyuYnwBqBkuymSVhzZTWPVNvBViMebtsLfXbRZXLmjbMirDsgOgOZtAVbjccJbCKEfc"
lllllllIIIIIlllIllIIIIIIllllIllIlIIIllllllIlIlIIIllllllIlllIII = "aFZrfjmqKstoGnFmmrhPjyEViqDZqvOLAVOIplhZtiVAqbzbWbnqpVlbLNYPmZRjCHKlTcxdekVEnqS"
T1655195574030295860 = 245
lIIIlIlIIllIllIIIIlIIlllIIIlIlIIlllllIIIIlIIlIlllllIIIIlII = "RAwKtHgmufxKAzHsdvaoRZubTHHdiHPStLeqrXcZKCjVrjhkdflXiwIfizQLTxbvEfzJlBLhAZwfunk"
U1655195574030295856 = "viDHAMFmdXfDRwobpsistybLWzwvddqHwWFVfYlUqnhkAxeyQloefvgWkBiTQDdGsNCrdpfYkqaecvz"
IIIllIllIllIIIlIllIlIllIlIIIIIIlIlllIlIlIllIIlIIlIIIIl = 257
sksXONDtNZvcQUNlvWOxNWKkkWNyEAPXSmedopNcXhvGPJtuEUEntBLKCNzzGnsTEHimoMWZLICpMes52 = "WmGrdBXyzWnpMMuZlXpWZKOnFmDRrbSJhDowRCgIfnWhimgGnvuETmKWLfotpFweFVqxuDBHFEuPcsn"
IlIIllIlIIIIlIllllIlIllIIlIIIlIIlIlIlIlIIlIIIlIlll = "akoSuUBdYooMlVLOutClHGMIJvaSPTsjCGkufmsUytpMuTQPoyZNqBCNKjOrZVcZLSvcSEkTCSYuEgR"
h48 = "UGHuVHDYRpYmPAqqHRCCITVHrrXLzalCqxkvZZgHdUkckQeFVdwcDgapvxariLpwjqFHWDrLimKpmky"
lIlIIIIllllIIIIIIlllllIIlllIlIlIIllIIIIIlIllll = "PVWXcMYGqPHjVezrdbCMCxpugOjHQxeJVAAeNWIPjecaqbOuvuUZUAPkkdrMjSrIGhfFRfqVyOMgtfe"
ZXvQWLPbXhljrrgJGKNHMqIZElkMOuLKcUQyEQwzfwPEBotvWWlyStCqXtPUBgFiCJKeZClXejGjKMX44 = 327
S1655195574028258842 = 252
nYhDlivkTeBYGrPtjGdtubuFHsbKnQRAlLAMFBEkyObzyYYtzzfoqPKKrZmiINReZEKaGeslaOhcqIK40 = "GGhWEzLfSVQcADyfsulBQoMNggxCpSNSvDaXpiCOpbJAmUPTdbPUwVbUItsACnvqiCvsQZjoXcShWmD"
mKwTuNfXnuIbcGMosjcbTMTkOmSRdyJpCkfbzGGftkrelhYKyENkyZMzkdyjBMtpdtszHtgAAkUVjwq38 = "pQBiLXXYfkoagvUmnIQrJqRTZHCIgHIkUEgtYTMtuVEbgJcouSLtfVBsLxQSgLNUlmJkySvtFhIEkve"
lIllIIIlIIlllllIllllIlIlIlIIIIIlllIl = 454
ZghzDFomJJAUqMREoJDlIzzGRHMjZeEfmMXjvtTfrMWCpvWYotguxbsHTZaHIUCNqQSEXTfEKuUBHMT34 = 113
R32 = 379
vFlonrAkxysVmmKPFIoUFTOyVDtFaBRjRiTwMjbdRxTNMOHyKzjmQsWEIMOFVSkwWIFBXQKTXHcAbkj30 = 139
aaaaAaAaaaAaAAAAaAAaAaaAaAaa = 114
DDDDDDDDDDDDDDDDDDDDDDDDDD = "nKZwSdkhZYtpjemhDVooPKxysPRSwSgWTjbvSuvDVSwdzlmGQWKzXvbbEQlQYZZcqyVLFhbbZbebRwM"
RRRRRRRRRRRRRRRRRRRRRRRR = 162
W22 = 897
lIlIlIlllllllIIIlIll = 230
t1655195574026285618 = 484
V16 = "VNqWILQaofDnSDRsPvzIYWuVDGxqmrHzpAtbmPdiLlaPBpfSoPbUNQZEuASCWDTmFfTiZswhSuxjxTX"
GwmSqsLsHWpRqWRwjsMhMuJCDayLWQesvHcStzRVXTkhndeObCbWabkoULXEEopxloPLqVVDohHlwgz14 = 348
IlIIIIlIIIlI = "mYFWPmedutepKbrfZkVhsrxMJolLvRwKVqLHXEZxFqQsyTlapURCslQfQCyxUMWyxJtNqWamiITkYrv"
g10 = "VzeaWOcBdXEhRUzMcjBVeDVltitiuBmoDRRbVsEAPyoEluDoarkbpqXnxkmYWBqremGXwEPHGnLQVPw"
r16551955740252838 = 292
eODEVcAAqdODvQVFhDrhQdmrQGRYbyyXVrWshDtrYXjluoHCWjTlKbLPzaYJVtsfeEOzkmqevPYJIhu6 = 138
IlII = "aperbSOOOTEQMPQVsZyvkVxxoBSTgkLONkJhIAifUaaEIdeDJiXWrzzrwrglMjkIafqrmvPGBWzrWSQ"
Aa = "jlDgcjrSPCYVAwfPHmmBqowPuAmwmnjfTkwsfiuLNBMZBpIynezkJaReYhhgnaObkvUpwcdWKBxLXoJ"

from sklearn.pipeline import FeatureUnion, Pipeline, _transform_one, _fit_transform_one
from sklearn.utils.metaestimators import available_if
import numpy as np

from joblib import Parallel, delayed


def _transform_one_xy(transformer, X, kk, weight, **fit_params):
    resX, J165519557401125811 = transformer.transform(X, kk)
    # if we have a weight for this transformer, multiply output
    if weight is None:
        return resX, J165519557401125811
    return resX * weight, J165519557401125811


class FeatureAugmentation(FeatureUnion):   
    def fit_transform(self, X, kk=None, **fit_params):
        self._validate_transformers()
        q3 = Parallel(h4=self.n_jobs)(
            delayed(_fit_transform_one)(trans, X, kk, weight,**fit_params)
            for name, trans, weight in self._iter())

        if not q3:
            # All o165519557401328335 are None
            return np.zeros((X.shape[0], 0))
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, o165519557401328335 = zip(*q3)
        self._update_transformer_list(o165519557401328335)
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = np.swapaxes(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, 0, 1)
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = np.swapaxes(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, 1, 2)
        return SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6    
    
    
    def transform(self, X):
        print("TRANSFORM")
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = Parallel(h4=self.n_jobs)(
            delayed(_transform_one)(trans, X, None, weight)
            for name, trans, weight in self._iter())
        
        if not SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6:
            # All o165519557401328335 are None
            return np.zeros((X.shape[0], 0))
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = np.swapaxes(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, 0, 1)
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = np.swapaxes(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, 1, 2)
        print("ahahah", SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6.shape)
        return SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6

class SampleAugmentation(FeatureUnion):
    def transform(self, X, kk):
        """Transform X separately by each transformer, concatenate results.

        Parameters
        ----------
        X : iterable or array-like, depending on o165519557401328335
            Input data to be transformed.

        Returns
        -------
        X_t : array-like or sparse matrix of \
                shape (n_samples, sum_n_components)
            The `hstack` of results of o165519557401328335. `sum_n_components` is the
            sum of `n_components` (output dimension) over o165519557401328335.
        """
        # print(self,np.array(X).shape, np.array(kk).shape)
        
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, a165519557401628312 = zip(*Parallel(h4=self.n_jobs)(
            delayed(_transform_one_xy)(trans, X, kk, weight)
            for name, trans, weight in self._iter()
        ))

        # for u in SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6:
        #     print(np.array(u).shape)
        # print(self,np.array(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6).shape, np.array(a165519557401628312).shape)
        
        if not SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6:
            # All o165519557401328335 are None
            return np.zeros((X.shape[0], 0)), np.zeros((kk.shape[0], 0))

        tttttttttttttt = np.vstack(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6)
        K1655195574017256315 = np.vstack(a165519557401628312)
        print(self, tttttttttttttt.shape, K1655195574017256315.shape)
        
        return tttttttttttttt, K1655195574017256315


# class Pipeline_XY(Pipeline):
#     def _validate_steps(self):
#         pass
#         # names, RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16 = zip(*self.steps)

#         # # validate names
#         # self._validate_names(names)

#         # # validate RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16
#         # o165519557401328335 = RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16[:-1]
#         # E18 = RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16[-1]

#         # for DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19 in o165519557401328335:
#         #     if DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19 is None or DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19 == "passthrough":
#         #         continue
#         #     if not (hasattr(DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, "fit") or hasattr(DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, "fit_transform")) or not hasattr(
#         #         DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, "transform"
#         #     ):
#         #         raise TypeError(
#         #             "All intermediate steps should be "
#         #             "o165519557401328335 and implement fit and transform "
#         #             "or be the string 'passthrough' "
#         #             "'%s' (type %s) doesn'DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19" % (DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, type(DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19))
#         #         )

#         # # We allow last E18 to be None as an identity transformation
#         # if (
#         #     E18 is not None
#         #     and E18 != "passthrough"
#         #     and not hasattr(E18, "fit")
#         # ):
#         #     raise TypeError(
#         #         "Last step of Pipeline should implement fit "
#         #         "or be the string 'passthrough'. "
#         #         "'%s' (type %s) doesn'DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19" % (E18, type(E18))
#         #     )


#     def _can_transform(self):
#         return self._final_estimator == "passthrough" or hasattr(
#             self._final_estimator, "transform"
#         )

#     @available_if(_can_transform)
#     def transform(self, X, kk = None):
#         """Transform the data, and apply `transform` with the final E18.

#         Call `transform` of each transformer in the pipeline. The transformed
#         data are finally passed to the final E18 that calls
#         `transform` method. Only valid if the final E18
#         implements `transform`.

#         This also works where final E18 is `None` in which case all prior
#         transformations are applied.

#         Parameters
#         ----------
#         X : iterable
#             Data to transform. Must fulfill input requirements of first step
#             of the pipeline.

#         Returns
#         -------
#         AaaAAaaAaAAaaAAaaaaaaA : ndarray of shape (n_samples, n_transformed_features)
#             Transformed data.
#         """
#         AaaAAaaAaAAaaAAaaaaaaA = X
#         k1655195574022259723 = kk
#         for _, _, transform in self._iter():
#             AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723 = transform.transform(AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723)
#         return AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723

#     def _can_inverse_transform(self):
#         return all(hasattr(DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, "inverse_transform") for _, _, DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19 in self._iter())

#     @available_if(_can_inverse_transform)
#     def inverse_transform(self, AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723 = None):
#         """Apply `inverse_transform` for each step in a reverse order.

#         All RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16 in the pipeline must support `inverse_transform`.

#         Parameters
#         ----------
#         AaaAAaaAaAAaaAAaaaaaaA : array-like of shape (n_samples, n_transformed_features)
#             Data samples, where ``n_samples`` is the number of samples and
#             ``n_features`` is the number of features. Must fulfill
#             input requirements of last step of pipeline's
#             ``inverse_transform`` method.

#         Returns
#         -------
#         AaaAAaaAaAAaaAAaaaaaaA : ndarray of shape (n_samples, n_features)
#             Inverse transformed data, that is, data in the original feature
#             space.
#         """
#         dddddddddddddddddddddddddd = reversed(list(self._iter()))
#         for _, _, transform in dddddddddddddddddddddddddd:
#             AaaAAaaAaAAaaAAaaaaaaA = transform.inverse_transform(AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723)
#         return AaaAAaaAaAAaaAAaaaaaaA

n = "vWzbcjCOSOfTMDVIUrtHVpyOAEejQKEcbaaydnmmYwxOVpWnxomUMSoYPXyzQaOzbsbBpJBeTvMbNRU"
IlI = 391
xMHDEdFAvjjJGCLiYVaSlTDthqMZUIHEzaSCEIRJeIKwfuThluhCKPyCPSboNZwPiWuATPBBdQolakB5 = 332
c7 = "lRGNbFrzlXlsmxfAthpfagGIokAkHhbGrPLlEFEDZkKpKCqhpYFLoFBnGCXsEaOiKwcxnfBdkhbLXbk"
llIIIIllI = 374
llIIlIIIlll = 347
aAaAaaaAAAaaa = 243
rfHDYhQUlMrbeEffvdqdTHKMzcqOFIJjRAVdSkIohwCgWCLaFRuMnQuDRBlekXbqZplWOhfDrEFqGrX15 = "aupoKXTSqSnRtrBPbqgWgudUWqNwHEVagmfNDCXoWiwPxgKVEintQlcanIrheMQkOmbnHTnlJEHkbhS"
yRhGGevLDktcUdRIEfsDvEjXuNkZYGjgUGDoRQCbbKkRLCTjSVJJVDfZRdDXKVrmIRbZNdDEdEFqSfL17 = 258
TTTTTTTTTTTTTTTTTTT = 291
lIIlIIllllIIIIIIIllII = 306
l23 = "SAGerhRZQSIRipWJuGOslwBuMvTgPQakkFfVUDzpEOdiCaCSFyuuOkiaqhsZTHwJQVOJmiXKHIELeMu"
t25 = 495
h27 = 691
p1655195574027258929 = "JQXbvNmsxNhqoIwWErfwRNsDUXeoVCFMzBabCpzqQHrWAWBDtHRKPWYVKOxjWZqiUZdZUAauDUZWCGp"
ivTqiJmZqASjhpnHqlroKwQcZeGNJGmYhTsayQbKZBceYqRYiLfbzTKxHaVhherLlpNOysgYhITvvHU31 = "fTAhzbtaRpCbzCmveIHILYkaFDGzjYndDfVZtlNGaujEsjlOqtvkIusppBZQvhAAkCAOlnlNnbuWftU"
s33 = "nFxutuMPWWtkZnYuGWQFMKuouRRBlKrYnuejPOrGqMfjqkRvCvbTZUERwvHLiQUIuABPEBLGnQQHCED"
s35 = "hyHddZjEEjPnlpXvBwNwhquvVxlyovePBhKBvDUqXeAyMJkxOIUhSKsJlcSiRvlsrLnNKoHbBtQflJF"
w1655195574028258837 = 379
llllIIIIIlIlllIIllIIllllIIlllIIllIlIIll = 215
lIlllllIlIllIIIlllIIlllllIIIlIllllIIIIIIl = "tIzTbkPMBCMNvitQWaphZNwBXuIjdkJZqJNczZPlhNtoierajgtqPfIAAMtauSCQYRURolAUWTxmQWU"
AaaaaaAAaAaAAAAaAaaAaaAaaAaaAaAAAAaAaAAAaAa = "lDfFjYmfAeRtyMjlYLAemiBFWdKSgJxuvEUyZHDEgXQemQZjmiySfeCTpHJecqzoETpvQjJBsUFIRGf"
ttttttttttttttttttttttttttttttttttttttttttttt = "oMlybQtYIHLkhxebaAuhxCbFAMcszivxKTOaZxqgGsDeVLOAHLqvTGyeszxhVwUGcDVIJfZFJGwZtiU"
gYRlPlHJclMqQmeurDmXKQwuPuFqwwAOYlLBcsIgEppsbVGwWCGiDGsldEjIRLFcoefOGahdCelKXWy47 = 469
L49 = 420
c165519557402925851 = 431
HZVrlLKGebVURLGOQXKxYDxuxMseceIBqvwkMzpVVpGydUHjQVbuByJecxuQLOazqHayYpegLcFxChQ53 = 569
x55 = "zOkWbsQRZfJLLYhIbuysLNeeUQzixKvONrcMbFyTxYoypOPkywgwLAzqVsJcFyTcQAYNyWbAlifQkTV"
AAAaaAAAAAAaaAAaaAAAAaAaAaAAAAaaaaAaAAAaaAAaAAAAaaaAaAaaa = "NcdZZYmAbjsbWIOhHlOWeYFuHNzHCRyLrIpGqmfYMzbJBwIIAkUxnHAnBmtFVaCksmMdAgPfpzcVMzP"
hqfwqOMNFGPtebGzLfMEjqjCqnYeUBDrReSFDZiUpOQtagXvMMwbbpwLdaNbLiJbHqgaLZatHeYSJrf59 = 310
O1655195574030295861 = 363
S1655195574031259563 = 432
AaAaAaaaAAAAaaAAAaAAAAaAaAaAaaaaAAaaaaaaaaAaAAaAAAAaAAaaAAaAaaAaa = 235
cdfIJzwBETSJDkDmdvzjGASSwZBnrIWZKQWnPPbexEsbwuedZAsbIqlKMaexFuMqnPBbkBFprBpPHrz67 = 291
PUHRenuyRLtPVFWVWrtTcUmaoadiPkqHlhGnixuAXRcVRXJlTuzYjbXCZpmXgtfifERYGbvRjrHBTVm69 = "tNdFItYDBRRQDhdHxMnfWvPPPeTAWivfonBBnEoyzTaiFywvovcmsuPxlhjxbkystvovlVEZDcqSplu"
PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP = 523
aAAAAaaaAaAAaAAaAAAaAAaAaAAAaaaaaaAaAaAAaAaaAaaAAAAAAAaaaaaaaAAAAaAaaAAaa = 622
IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII = "cXVtMhFNwNwKrBEbMAtSAsLXmAdzeaHjeHryCJVyTsxgsJkfzrdFZuAJKxHsMSdwriNScFOxHvMjmax"
GeOtMdTtHtyftLvJOMHoyuGDDUWKnOPiUmPAkwfILEqZmwRUZXOvYJEkTWPqkPukcassEMIFFMPBnID77 = 310
t79 = 221
qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq = 225
aAaaAaaAaAaAAaAAAAAaaaAaaaAAAAAAaaaAAaaAaAAaAaAAaaAaAAAaaAAAAaaAaaaaAaAAAaAAaaAaAaa = "DgatoFkOiIisphdFzrDjxElaAOtfIqAdPYFyVIvATdNqmrRVSSWfvHwtiGsgeeniYbVAonVkHUauHOM"
ppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppp = "oSNzUymCZvjNLIaeeVaZjsAvQowYVLoJHmFuXXTVeIwpcUCTaHBWdOZYUnsFCxmKkiaLeSPKfcHWYCe"
QePvhiUmSOZtkpIVhzCRIKmoUfinTXWgsoarjdfNPRiHgvDmceahlQcdgZQcLiFLmPqgfpqAmsfHExT87 = 182
QKHqvWoBIjruEyiDuUQFRgmKbpZadUyidmGWgpDvAwLEDhbctQhNscvkNpOrcLIZsYEKSvBKMVaXcqI89 = 468
kkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk = "fXuUCjsGRJKpzUPUvQpqjLPVOyeHujFwkFGXhSBCFVNFIjspIqltgsmeOGqAGOZAtYFSOECKmDFhECU"
x165519557403325993 = 230
c95 = 347
M97 = "GfVvPirntTmJpfKDLEFJkBcTMdywrWdGreJPsYafrPfGUIQEBEAZbvvzXGsigjpSeOMxRjkxmgkJOut"
i99 = "FmOdGOQcwPwjoUAkbPhjGmrieRpuJaPWrakTujGkyXXNAZudcqFlMpOHqdNKYrnMwjczCYKCuqAgSyP"
j101 = 188
JEdKaTskEMxcfgZsihRtgSedTuZFBMeXOmAtjFBmydBXGgxLOJCNFiWNIZeKOHMqEqJpMADoFjVNLLx103 = 584
b105 = 119
Q107 = 353
k109 = 53
aAaaaAaaaAAAAAaaAAaAaAAaAAaaAAaAaAAaAAAaaaAAAaAaaaAaAaAAaAAaaAAaaAAaAaaAaAaaAaAaAaaaAaaaAAAaAAAAaAaaaaAaaaAAaAa = "DruqGDuLeUnAhIoMUrqDcBsBmyqYGZvIhtOUgAHLfcHbfToWyGPYAOHdXxCkVKTmZHKrqAiPPvNCRdZ"
iAOqWDNpzVSauqvAgGqWQrgiOLHiSVToDFTREopHzsVskhCbATRMaTubmudNGvldzHOySXJRcUSirwQ113 = "DgmdiPIxHojykvkhxvGoqafzztskJCLsqAPTJewsZMOmJcsniwkjvMpYGzaqlVPEwjzIUxPocyFZksG"
AAAAaAAaaaaaAAAaAAAAaaaaAAAaaaAaAaaaAaaAAaaAAAaaaAAaAaAaaaaaaAAaAAaaaaaaAAaAAAaaaaAaAaAAAaaAaAaAAAaAaaaaaaAaaaaaAAA = 785
m117 = 112
RTyIWNqBOotnMrLTLwOytWQGqKIWxHftwSWrsaZggbhsLFQXUxuePMEzSInYbZutjSRsnBYgbkzfaBZ119 = "CcJXreHfindlEhcFPNYXdftRwCoiiWDbZYRkUQhTEelcDEXOMpAFtWsbtpOUMXzPZwzQcvTAXvxHQSB"
T1655195574036285121 = "VLmnPDdWYYzzSRkXJrRdftgbUTwHiXrgBqjeaQizFtSfVyTahxbgcINRowaGkXaucedccbWZnjvnGFN"
lIlIIIIlIllIlIlIlIIlIIlIlIIllIIIlIlIIIIlIIlIlIlIlllIIIlllIIIIlIIIllIlIlllIlIIIIIlIIIlIlIllIIIIlllIIlIIlllIlIIIlllIIlllIIIll = "GFbGoIqvDsQVavRJOwMvCjxeFECFmjQwJuAuaDwUniseprajAUmlJjGOdEswCBnwiDjIQHMUhqPWsKr"
XorpvKrZdXHJMuAICTwOfTLRVTEtiladINUKmkUXfmJqBVxmxqcNirHbFVMwNOuXxTsiGDkfKFEOdez125 = "VaFEGIllNHigTpUvrDDGMBIFiCYJncGfgqfyliXkmncsxRtBKYNVQPpNGNXjOmVJOilsSHLQKkBeMJV"
v127 = "ulEZWgEEUHoFUwIUDPTSGCVneiRBNPQfyTompmRoEQDiaoXbptHYDtxiShtrbfKrCkOWuLcMqqwURpK"
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA = "zyVSNSIoIiEwclYrWVGFWkQswSiNbcIpqUyGKquuVtiDwsWdYcdolwzGhzIzxfCMGKIHgCqPDNmUbMq"
F1655195574038284131 = 255
u133 = "iPZIKGJtrngPsAhyMDqhNPZWrpQKNxWacqKFFVYEjyZzFgjaJUYShjYLtyncJKNsbDLZeaGDpzzLepT"
aAAAaaaaAAAaAAaAAAaAaAAaAAAAaAAaaaaaAaAaaaAaaaaaaaAAAaaaAAaAAAaAaAaaaAAAaAaaaAaAAaaAaAaAAAaAaaaAAaaaaaaAaAaaAAAAaAAAAAAAAAaAAAaaAaAAAAA = 222
O1655195574038284137 = 84
T1655195574038284139 = "RqrRjlohimDbCALSyYIazbiIRIVHjQTzlXHYbMfgiRjIAUXGGvaxpTUaAwrMQxtPBAekVSsQBWKqauY"
AaAaAaAaAAAAaaaAaAAAAaAaaAaaAaAAAaAAaAAaaAaaAaAAAaAaAaaaaAAaaAAaAaaaAAAaaaAAAaAAAAAAaAAaAaAaaaAAaAAAAAAAaaAaAAaAAaaaAAaaaaaAAaaaAAaAaAaAAaAaa = 549
WxTrJEZlimuAcWercHZFlXWdYBhhIIQfuvyTWVvwaTElydnPdFSTYzlJqycbtBcGIkVuiOVsBkBmGnL143 = 258
l145 = "yIeOjwuWSpSWhRJYUGhLJjFuwtXzMGQucVEAvHERYBoQnjwOnXrFgJIhRFMDxXxswwtRtYKcqXryzko"
TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT = "yVYxxhYRPyXFFYLXovrOhJUECixIGxUCXeUOyCyMNgNCMxTPxjCqIGaBGOTtMmAgCvwnrAWpaWjWXWP"
x16551955740392818149 = "cFtXyJxRjQGQiRGAPAiiYgZIZhcmILvahWpXKtywqjSWqWBNGJBcUBBpcAMNPnBuuxATUPlSxaRVffu"
lIIIllIIIIlIlIllIllIllIIIIlllIIIIIlIllIllIllIlIIIlIIIlllIIIlllIIIIlllIIIIIIlIIIIIIIIIIIIIlllIlIlIIIIllIIlIlIlIlllIIlIlIllllllIlIlllllIIIlIllIllllllIllI = 131
e153 = 691
g16551955740402787155 = 336
X157 = "WllyyiBDENipYlDZizdFnCgsUWWBAnsYLyVQZQGmEKchVfddSrNmLEZypMrqHKgBVkjzzPALmnJhrnP"
u1655195574041256159 = "CImSnkGSzeJGFNbcJRaexVkexeTXnAwDkZawnRvRuVjdHXjVhNVnLYFOGapYgDiBLMszOVMDnRrUosf"
TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT = 604
t163 = 544
egVVKpztAcfpsIGypkUdWJDaMJdtRRtVgJdzLWJxJLfRbODTOjotfpySabGQyYkWrvdfQiYaazezRON165 = "oeZGyDywAjauiyTDFjacaDeDuTNutQngRwquscuMtWUDotqhErCcQdSHuhTesfRkdEiQbDhLvXdOaBK"
PpJauTgKDWEsoyuyREmLdpSWmDqlcnImcHNPlQYlfKxsFLQtPgOljsPZIkeIrgvxYDCMxOdenLDtOGW167 = "yLmTPIfnuIfbMXPSuQHhjfGRDHfKUmOaTFHiwhorIsibHraNIGyevOwsnGsLnPInAKFeYkMFfSsIuvB"
w16551955740422573169 = 160
M171 = 255
GGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGG = "qtIlzzBEhzDUMoNOmpExgqTiDgjerCrqThPQdWJxHJHFucMfTRgwMpTRhyMxXITgfhcvByWWQQdescm"
Z175 = "LvtfFoLfeYhQLUnzWVPjfvNWNBUSgwIdLwyUExhIEtpbqRDXreFTNQfJJhZvbkAeWhqCcfHAtdktVGe"
nYHlDhXarIdcAjSstWiZZPrMatHJgwNvcxkNRWgAIwPdBzvuJZXlXjdWWapvoHzHXsQvBVZJSbfyaZu177 = 345
P179 = 215
AaaAAAaaAAaAAAAaAaAAAaaAAaAAAAAaAAaAAaaAAAAaaAaaaaaaaAaaAAaAAaaAaaAaAAAAaaAAAAaAAAAAaaAAAAAAAAAAaaaAaaAAAaaaaAaaAAaaaAAAaAaaaAAaaAAAAaaaaaaaaAaaaaaaAAAAAAAAaAaAaAAaAaaaaAAAaAaaaAaaA = 127
llIIlIlIlllIIIlIlllIlIllIllIlIIIllIIIIlllIllIlIllIIIIIIlIIIIlIlIIIlllIlIIlIIlIlllIlIIlIlIIIllllIIllIIlIIIIIlIIllIllllIIlIllllIIIlIIllIllIIlllllIIIIlIllIlIlIIlIIIIllIIIlIIlIllllIlIIIll = "RQnWTUVPVpovWELAleLVFlByzGRKhKqsmNcIqGNhtgNOFXPzrqaCxAtlFfjyQivkujConkwSleGKwUw"
IlIlIIIllIIllIlIIllllIIlllIIIIlllIlIllIIlllIlIIllIlIlIlIlllIllIlIlIlIlIIIlIlllIllllIlIIIIlIlIIllIIllIllIIIIIIIllIlIIIIllIIlIlIllIlIllIllllIlIIIlIlIlIlIIlllIIIIllIIllllIlIIIlllIllIlIllll = "etoqcIUmCbLeFAdAgRjbtEYLYkFfcGkjNekMPvlgSQJUjQmZszVpFSQOzgdDzCbEQXqtDDahCdqvzee"
llllIlIIIIllIIlIlIIlIlIlIIlIllIIlIIlllIllllIIlIllIllIllIIIlIIlIIlIlIIIlllIIIlllIIIllIlllllIlIIlIllllIllIIIIIIlIIIIIlIIlIIIIIIllIllIlIllIIIlIIIlIlIIIllIllIllllIllIllIlllIlIIIIlIIlIlIIIlIlI = 546
i1655195574044286189 = 404
D16551955740452836191 = "bFrmUWDurPAGbKqvNiFzzrBLGbMhlaWyAhwzaukWfEnNgHoGsGGHcJonmniygxJgfJlCbwezFkCmiLE"
aaAAaaaaaaaaAaaAAaAAaaaaaaAAaaaaaaAAaaaaaAAAaAaAaAAAAAaAAAaAaAaAaAaaAAaAaaAAaAaAAAAaAAAAaaAAaaAAaAaAaaAaaaaAAAAAaAaAaAAAAaAAaAAaAaaAaAaaAaAaaAaAaaAaAAaaaAAAAaAaaaAAaAAaaAaaaAAaAaaaaAaAAaaAaAAaa = 269
aAaaaAaaAaaaAaAAaaAaAAaAAaAAaaAaAaAAaaAAAAaaAAaAaAAaaaaaAaAAaaaaAaaAAaaaAAaAAAAAaaAAAaaaAaAaaaAaaaAaAaAAaaAAaaAaaaaaAaaaAaaaAAaAAAaaaAaAaaAaaAaAAaaAAaaaAAAaAAAAAaaaAaaaAaAAaaAaaaaaAaaAaaAAAAaAaaA = 319
NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN = 51
QVSAyzjlbcxqZQyQqKcGixtJMtjMhpmCGxZLSYlXrgxznMxadiZfPaEnScNbjfSlccpZZosTHovDMRs199 = 317
SqKoeiepOAbrlypulDYNKwHhKeqMAWayVwsYLTlUjNWNGLfLXGITLceMkEnoycomKXsIyHBCtUptsPX201 = "CItDxseXryJJRWrNBlWzfHxrdmPfYSLNxmpUVZByKrcPXYlHyXjhbZtaoDgSDcjVctIYxYSwgytbXlQ"
LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL = 340
IlllIllIlIIllllIIlIlIllIIlIlIIlllllIIllIllIllllllIlllIlIIIllIlIIIlIllIIIllIIIllIIlIIIIllIIlIIlllIllIIIlIlIIllllIIIIIllIlIlIlIIlIlIlIIllllIlIllIlIlIllIlIIllIlIIIIllIIIIIIIIIllIIllIIlllIIIllIlIIIllllIIIlllII = 591
WBgwahgLOkZfToYeHtcNImmuLIwhTKxLDQXkmUmUzUQBgUtnfgIAotMzSCNBGgwSasTsoYlyImAIjRZ207 = 270
PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP = "TBtsGIkxSPdDeXXKuwZvuyJOjqvpKGEuEAMHvstabcMVsCwduKaSeLIDwcHogoRKBObGvbIANuNvTET"
g16551955740482845211 = 393
AaAAaaaAaAAaAaAAaaAaaAaAAaaAAAAAAaaaaaaAaaAAaaAaaaAAaAAaAaAaaAAaAAaAAAaaaaAaAaaAAaaaAaaaAaAAAAaAAAAaaAaAaAaAAAaAAAaAAAAAaaAaaAaAaaAaaaaaaaaaAAaaAAaAaaaaaaaaaAaaaaaAAaaaaaAaaAAAAAAaAAAAaAAAaAaaaaaAAAaaaAaaaAAaAAaAa = "SwjlzzZdIuJhgxPHCCHamiQfIhSodpvLSxoYlNlOUnRBHKJRToXyxkPapbPmftHTTvzclYRSIyHdCwe"
AaaaAAAAAaAAaAaAaaaAaAaAAaaaAaaaAaAaaAAaaAaaAAAAAAAaaAaAaaaaaAAAaAAAAAAAAaaAAAaaAaaAAaaAAaAAaAaAAaAaaaAaaaAAaAAaAaAaAaaaaaAAaAaaAaaAaaAAAAAaaaaAAaAaaaaaaaAaaaaaAaaaaAAaAAaAAaaAAAAAAaAAaaAaAAaAAaaaAaaAaaaaaaAaaaAaAaa = 569
I16551955740492582217 = 399
AaAaAAaAAAAAAAaaAaaaAAAAaAaAaaAAaaAaaAaaAaaaaAAaAaAaAaaAaAAaaaaaAaaAAaaaaAaaaaaaAAaAaaaAAaaaAaaaaaaaaAAAaAAaaAAaaAaAAaaaaaaAaAaAAAaaaaAaaaAAaaaAaAaAaAaaAAAAaAAaaAAAaaaAAAaAAAAAaAAAAaAaAAaAAAAAAAAaaAAaaaaaaAaaAAAaaaaAAAA = "dqCdHeJgjdHAJzOUyVrgcfDqIxgaLBDExpSYhxmFFroQwJIJYRUldqCWETINcRkMEkMUaTjRExESZzX"
mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm = "BECTxEecqzswqIWnEFHowoWLSgPWZwDVyxarcSTzveXZtzmpdlIpofgnGlvwFbjlIzKihXYRVlzjvHd"
R223 = "vCNPeyOqaCTMqdHCvbtDNxdwBCrcPklTLYkcHmixGTcYczbtMbomMrASAPBgHLuPnGgzKdIVUfgPiDe"